ziggy.GraphReduce.GraphLoader.GraphLoader

Package ziggy :: Package GraphReduce :: Module GraphLoader :: Class GraphLoader |
[hide private]
[frames] | no frames]

# Class GraphLoader

source code

Provides graph handles in Hadoop MapReduce

Instance Methods | [hide private]
__init__(self, G=None, graph_handle=None) Constructor | source code
read_edgelist(self, filename) | source code
read_adjlist(self, filename, undirected=True) | source code
write_adjlist(self, filename=None) | source code
write_edgelist(self, filename) | source code
in_hdfs(self) | source code